@@ -283,6 +283,37 @@ def default_get_function(req, local_path, **options):
     return Response(f.read(), mimetype='application/octet-stream')
 
 
+def streaming_get_function(req, local_path, **options):
+  ''' Define the streaming version of the `get` method.
+
+  Returns the file content located at <local_path>.
+
+  Args:
+    req (flask.request):
+        The request instance given by Flask.
+    local_path (str):
+        The absolute path to the requested resource.
+    **options:
+        Arbitrary option arguments.
+        Currently no option is passed to this function.
+
+  Returns:
+    flask.Response:
+        A response message.
+  '''
+  bufsize = options.get('bufsize', 65535)
+  def is_active(FileStream):
+    b = FileStream.read(1)
+    FileStream.seek(-1,1)
+    return bool(b)
+  def streaming():
+    with open(local_path, 'rb') as f:
+      n_read = bufsize
+      while is_active(f):
+        yield f.read(bufsize)
+  return Response(streaming(), mimetype='application/octet-stream')
+
+
 def get(req, target, **options):
   ''' Provide the `get` method.
 
@@ -357,11 +388,20 @@ def default_dump_function(req, local_paths, **options):
     flask.Response:
         A response message.
   '''
-  buf = io.BytesIO()
-  with tarfile.open(fileobj=buf, mode='w') as arv:
-    for filename in local_paths: arv.add(filename)
-  buf.seek(0)
-  return Response(buf.read(), mimetype='application/octet-stream')
+  def streaming():
+    buf = io.BytesIO()
+    with tarfile.open(fileobj=buf, mode='w') as arv:
+      for filename in local_paths:
+        pos = buf.tell()
+        basename = os.path.basename(filename)
+        arv.add(filename, arcname=basename)
+        buf.seek(pos)
+        yield buf.read()
+        ## the stream position should be set something but zero.
+        ## an init process is called when the stream position is zero.
+        buf.seek(1)
+        buf.truncate(1)
+  return Response(streaming(), mimetype='application/octet-stream')
 
 
 def dump(req, filelist, **options):
